@@ -11,7 +11,7 @@
 /**
  * Moonyのバージョン
  */
-define('MOONY_VERSION', '0.10.0');
+define('MOONY_VERSION', '0.10.1');
 
 /**
  * 内部エンコーディング
@@ -134,16 +134,6 @@ define('MOONY_LOG_CATEGORY', MOONY_LOG_LEVEL_INFO);
  */
 define('MOONY_LOG_ROTATE', true);
 
-/**
- * アクションクラスの拡張子
- */
-define('MOONY_ACTION_EXT', 'php');
-
-/**
- * テンプレートファイルの拡張子
- */
-define('MOONY_SMARTY_TEMPLATE_EXT', 'tpl');
-
 /**
  * Moonyを構成するファイルのinclude
  */
@@ -184,11 +174,14 @@ class Moony
     /** @var string テンプレートファイルを格納するディレクトリ */
     var $template_dir = 'template';
 
+    /** @var string テンプレートファイルのコンパイル結果などを格納する作業用ディレクトリ */
+    var $work_dir = 'work';
+
     /** @var string ログファイルの出力先ディレクトリ */
     var $log_dir = 'log';
 
-    /** @var string テンプレートファイルのコンパイル結果などを格納する作業用ディレクトリ */
-    var $work_dir = 'work';
+    /** @var string テンプレートファイルの拡張子 */
+    var $template_extension = 'tpl';
 
     /** @var string テンプレートファイルの左側区切り文字 */
     var $left_delimiter = '{';
@@ -252,8 +245,9 @@ class Moony
         define('MOONY_SMARTY_TEMPLATE_DIR', $this->template_dir);
         define('MOONY_SMARTY_WORK_DIR', $this->work_dir);
         define('MOONY_LOG_DIR', $this->log_dir);
-        define('MOONY_LEFT_DELIMITER', $this->left_delimiter);
-        define('MOONY_RIGHT_DELIMITER', $this->right_delimiter);
+        define('MOONY_SMARTY_TEMPLATE_EXTENSION', $this->template_extension);
+        define('MOONY_SMARTY_LEFT_DELIMITER', $this->left_delimiter);
+        define('MOONY_SMARTY_RIGHT_DELIMITER', $this->right_delimiter);
 
         // コントローラ生成、処理開始
         $controller =& new Moony_Controller();
@@ -284,6 +278,18 @@ class Moony
         $this->template_dir = $template_dir;
     }
 
+    /**
+     * テンプレートファイルのコンパイル結果などを格納する作業用ディレクトリを
+     * 設定します。初期値として「work」が設定されています。
+     *
+     * @access public
+     * @param string $work_dir テンプレートファイルのコンパイル結果などを格納する作業用ディレクトリ
+     */
+    function setWorkDir($work_dir)
+    {
+        $this->work_dir = $work_dir;
+    }
+
     /**
      * ログファイルの出力先ディレクトリを
      * 設定します。初期値として「log」が設定されています。
@@ -297,15 +303,15 @@ class Moony
     }
 
     /**
-     * テンプレートファイルのコンパイル結果などを格納する作業用ディレクトリを
-     * 設定します。初期値として「work」が設定されています。
+     * テンプレートファイルの拡張子を設定します。
+     * 初期値として「tpl」が設定されています。
      *
      * @access public
-     * @param string $work_dir テンプレートファイルのコンパイル結果などを格納する作業用ディレクトリ
+     * @param string $template_extension テンプレートファイルの拡張子
      */
-    function setWorkDir($work_dir)
+    function setTemplateExtension($template_extension)
     {
-        $this->work_dir = $work_dir;
+        $this->template_extension = $template_extension;
     }
 
     /**
