@@ -44,15 +44,12 @@ class Moony_Controller
         $router->route();
         $action_name = $router->getActionName();
 
-        // デフォルトテンプレート名
-        $template = Moony_Utils::buildPath('', $action_name, MOONY_SMARTY_TEMPLATE_EXT);
-
         // Request生成
         $request =& new Moony_Request();
 
         // Response生成
         $response =& new Moony_Response();
-        $response->setTemplate($template);
+        $response->setTemplate($action_name);
 
         // Session生成、設定に応じて開始
         $session =& new Moony_Session();
@@ -72,13 +69,9 @@ class Moony_Controller
 
         // アクション生成
         $action = null;
-        $action_path = Moony_Utils::buildPath(MOONY_ACTION_DIR, $action_name, MOONY_ACTION_EXT);
-        if (file_exists($action_path)) {
-            include_once $action_path;
-            if (class_exists($action_name)) {
-                // インスタンス生成
-                $action =& new $action_name;
-            }
+        if (Moony_Loader::loadClass($action_name, MOONY_ACTION_DIR)) {
+            // インスタンス生成
+            $action =& new $action_name;
         }
 
         // アクションの処理
@@ -105,15 +98,9 @@ class Moony_Controller
             // 入力値検証
             if (method_exists($action, 'validate')) {
 
+                // Validator生成
                 $validator =& new Moony_Validator(&$request);
-
-                // 前回表示内容を取得、
-                // 使用したテンプレートファイル名をValidatorにセット
-                $prev_response = null;
-                if ($session->exists(MOONY_PREVIOUS_RESPONSE_NAME)) {
-                    $prev_response = $session->get(MOONY_PREVIOUS_RESPONSE_NAME);
-                    $validator->setTemplate($prev_response->getTemplate());
-                }
+                $validator->setTemplate($action_name);
 
                 // 検証
                 $action->validate(&$validator);
@@ -125,6 +112,10 @@ class Moony_Controller
                     $this->processEnd(&$response, &$session, &$flash);
 
                     // 前回テンプレート設定内容を設定
+                    $prev_response = null;
+                    if ($session->exists(MOONY_PREVIOUS_RESPONSE_NAME)) {
+                        $prev_response = $session->get(MOONY_PREVIOUS_RESPONSE_NAME);
+                    }
                     if (!is_null($prev_response)) {
                         // 再度エスケープする必要はない
                         $response->setAll($prev_response->getAll(), false);
