@@ -184,12 +184,20 @@ class Moony_Validator
                 }
                 break;
             case MOONY_VALIDATE_KATAKANA :
-                if (Moony_Checker::isRegexMb($value, '^([ァ-ヶ]|[ー])*$')) {
+                $value = Moony_Utils::toArray($value);
+                if (MOONY_INTERNAL_ENCODING != 'EUC-JP') {
+                    mb_convert_variables('EUC-JP', MOONY_INTERNAL_ENCODING, &$value);
+                }
+                if (Moony_Checker::isRegex($value, '/^(\xA5[\xA1-\xF6]|[\xA1\xBC])+$/')) {
                     return true;
                 }
                 break;
             case MOONY_VALIDATE_HIRAGANA :
-                if (Moony_Checker::isRegexMb($value, '^([ぁ-ん]|[ー])*$')) {
+                $value = Moony_Utils::toArray($value);
+                if (MOONY_INTERNAL_ENCODING != 'EUC-JP') {
+                    mb_convert_variables('EUC-JP', MOONY_INTERNAL_ENCODING, &$value);
+                }
+                if (Moony_Checker::isRegex($value, '/^(\xA4[\xA1-\xF3]|[\xA1\xBC])+$/')) {
                     return true;
                 }
                 break;
@@ -240,6 +248,7 @@ class Moony_Validator
     /**
      * エラー時に使用する
      * テンプレートファイル名を設定します。
+     * 拡張子を除いた名称を設定してください。
      *
      * @access public
      * @param string $template テンプレートファイル名
