@@ -31,13 +31,14 @@ class Moony_View
      */
     function Moony_View()
     {
+        // Smarty設定
         $this->smarty = new Smarty();
         $this->smarty->template_dir = MOONY_SMARTY_TEMPLATE_DIR;
         $this->smarty->config_dir = MOONY_SMARTY_TEMPLATE_DIR;
         $this->smarty->compile_dir = MOONY_SMARTY_WORK_DIR;
         $this->smarty->cache_dir = MOONY_SMARTY_WORK_DIR;
-        $this->smarty->left_delimiter = MOONY_LEFT_DELIMITER;
-        $this->smarty->right_delimiter = MOONY_RIGHT_DELIMITER;
+        $this->smarty->left_delimiter = MOONY_SMARTY_LEFT_DELIMITER;
+        $this->smarty->right_delimiter = MOONY_SMARTY_RIGHT_DELIMITER;
 
         // エンコーディングが異なっている場合にフィルタ
         if (MOONY_TEMPLATE_ENCODING != MOONY_INTERNAL_ENCODING) {
@@ -60,8 +61,10 @@ class Moony_View
      */
     function render(&$response)
     {
+        // テンプレート名称
+        $template = Moony_Utils::buildPath('', $response->getTemplate(), MOONY_SMARTY_TEMPLATE_EXTENSION);
+
         // テンプレート存在チェック
-        $template = $response->getTemplate();
         if (!$this->smarty->template_exists($template)) {
             Moony_Logger::warn('Template file not found: ' . $template, __FILE__, __LINE__);
             Moony_Error::notFound();
